=====
Tools
=====

A tool in Pharmpy is an implementation of a pharmacometric method. A tool performs some kind of preprocessing, running
of models, postprocessing and creation of results in the form of a workflow.

~~~~~~~~~~~~~~~~
Tools in Pharmpy
~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   modelsearch
   iivsearch

~~~~~~~~~~~~~~~~~~~~~~
Tools connected to PsN
~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   bootstrap
   cdd
   crossval
   frem
   linearize
   qa
   resmod <psn_resmod>
   scm
   simeval

